@@ -43,7 +43,6 @@ class SDTable(SDFirstClassObject):
                 self.__setattr__('_swagger_tickets', getattr(self._swagger_table, 'open_tickets'))
 
     def open_ticket(self, user_id, device_id, number_of_people_in_party=1, business_expense=False, custom_ticket_name=None, return_ticket_details=False):
-
         """
 
         :param user_id:
@@ -67,19 +66,15 @@ class SDTable(SDFirstClassObject):
         else:
             raise KeyError('Table missing key data')
 
-        print ticket_body
-
         #Send the request
         ticket_response = self._swagger_locations_api.createTicket(self.location._location_id, self._api_key, ticket_type='dine-in', body=ticket_body)
 
-        print ticket_response.ticket_id
-
         if return_ticket_details:
             #Get the totals
-            return SDTicket(self._api_client, ticket_response.ticket_id, user_id)
+            return SDTicket(parent=self, location=self.location, ticket_id=ticket_response.ticket_id, user_id=user_id, get_values=True)
 
         else:
-            return SDTicket(self._api_client, ticket_response.ticket_id, user_id)
+            return SDTicket(parent=self, location=self.location, ticket_id=ticket_response.ticket_id, user_id=user_id, get_values=False)
 
     @property
     def open_tickets(self):
