@@ -1,7 +1,7 @@
 __author__ = 'gsibble'
 
 from base_types import SDFirstClassObject
-import constants as C
+import exceptions as Exceptions
 
 class SDTicket(SDFirstClassObject):
     def __init__(self, parent, location, ticket_id, user_id=0, get_values=True, swagger_ticket=None, *args, **kwargs):
@@ -53,11 +53,19 @@ class SDTicket(SDFirstClassObject):
         :return: :raise:
         """
         if hasattr(self, 'user_id') and hasattr(self, 'ticket_id'):
-            if self.user_id is not None and self.ticket_id is not None:
+
+            #If we don't have a user_id, use the default user of 0
+            if self.user_id is None:
+                user_id = 0
+
+            #But if we do have a user, use them
+            else:
+                user_id = self.user_id
+
+            if self.ticket_id is not None:
                 post_body = {
                     'item_id': int(item_id),
-                    'quantity': quantity,
-
+                    'quantity': quantity
                     }
 
                 if instructions is not None:
@@ -66,21 +74,20 @@ class SDTicket(SDFirstClassObject):
                 if modifiers is not None:
                     post_body['modifiers'] = modifiers
 
-                print post_body
+                #print post_body
 
                 returned_status = self._swagger_locations_api.addItemsToOrder(location_id=self.location.location_id,
                                                                               ticket_id=self.ticket_id,
-                                                                              user_id=self.user_id,
+                                                                              user_id=user_id,
                                                                               api_key=self._api_key,
                                                                               body=post_body)
 
                 return returned_status
-
             else:
 
-                raise C.NoUserSetOnTicket
+                raise Exceptions.NoTicketID
         else:
-            raise C.NoUserSetOnTicket
+            raise Exceptions.NoUserSetOnTicket
 
     def submit_order(self):
         """
@@ -89,19 +96,24 @@ class SDTicket(SDFirstClassObject):
         :return: :raise:
         """
         if hasattr(self, 'user_id') and hasattr(self, 'ticket_id'):
-            if self.user_id is not None and self.ticket_id is not None:
 
+            #If we don't have a connected user, use the default user 0
+            if self.user_id is None:
+                user_id = 0
+            else:
+                user_id = self.user_id
+
+            if self.ticket_id is not None:
                 returned_status = self._swagger_locations_api.submitOrder(location_id=self.location.location_id,
                                                                           ticket_id=self.ticket_id,
-                                                                          user_id=self.user_id,
-                                                                          api_key=self._api_key,
-                                                                          body={'send': True})
+                                                                          user_id=user_id,
+                                                                          api_key=self._api_key)
 
                 return returned_status
             else:
-                raise C.NoUserSetOnTicket
+                raise Exceptions.NoTicketID
         else:
-            raise C.NoUserSetOnTicket
+            raise Exceptions.NoUserSetOnTicket
 
     def add_discount(self, discount_type_id, discount, user_id=0):
         """
@@ -127,4 +139,34 @@ class SDTicket(SDFirstClassObject):
 
         self.refresh()
 
-        return discountStatus
\ No newline at end of file
+        return discountStatus
+
+    def pay_with_external_source(self, amount, tip_amount, user_id, device_id, tender_type_id, payment_source_name):
+
+        payment_body = {
+          "payment_source_name": payment_source_name,
+          "tip_amount": tip_amount,
+          "amount_before_tip": amount,
+          "tender_type_id": tender_type_id,
+          "user_id": user_id,
+          "device_id": device_id
+        }
+
+        paymentStatus = self._swagger_locations_api.addExternalPaymentToTicket(location_id=self.location.location_id,
+                                                                               ticket_id=self.ticket_id,
+                                                                               body=payment_body,
+                                                                               api_key=self._api_key)
+        self.refresh()
+
+        return paymentStatus
+
+    def void(self):
+        voidStatus = self._swagger_locations_api.voidTicket(location_id=self.location.location_id,
+                                                            ticket_id=self.ticket_id,
+                                                            api_key=self._api_key)
+
+        return voidStatus
+
+    def cancel(self):
+
+        return self.void()
\ No newline at end of file
